/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.pagespeedonline.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for Result.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the PageSpeed Insights API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Result extends GenericJson {

  /**
   * Localized Page Speed results. Contains a ruleResults entry for each Page Speed rule
   * instantiated and run by the server.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private FormattedResults formattedResults;

  /**
   * Canonicalized and final URL for the document, after following page redirects (if any).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * List of rules that were specified in the request, but which the server did not know how to
   * instantiate.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> invalidRules;

  /**
   * Kind of result.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Notice to discourage users from reusing API keys.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String notice;

  /**
   * Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private PageStats pageStats;

  /**
   * Echo of certain request parameters.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Request request;

  /**
   * Response code for the document. 200 indicates a normal page load. 4xx/5xx indicates an error.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer responseCode;

  /**
   * The Page Speed Score (0-100), which indicates how much faster a page could be. A high score
   * indicates little room for improvement, while a lower score indicates more room for improvement.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer score;

  /**
   * Base64 encoded screenshot of the page that was analyzed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Screenshot screenshot;

  /**
   * Title of the page, as displayed in the browser's title bar.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The version of the Page Speed SDK used to generate these results.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Version version;

  /**
   * Localized Page Speed results. Contains a ruleResults entry for each Page Speed rule
   * instantiated and run by the server.
   * The value returned may be {@code null}.
   */
  public FormattedResults getFormattedResults() {
    return formattedResults;
  }

  /**
   * Localized Page Speed results. Contains a ruleResults entry for each Page Speed rule
   * instantiated and run by the server.
   * The value set may be {@code null}.
   */
  public Result setFormattedResults(FormattedResults formattedResults) {
    this.formattedResults = formattedResults;
    return this;
  }

  /**
   * Canonicalized and final URL for the document, after following page redirects (if any).
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Canonicalized and final URL for the document, after following page redirects (if any).
   * The value set may be {@code null}.
   */
  public Result setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * List of rules that were specified in the request, but which the server did not know how to
   * instantiate.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getInvalidRules() {
    return invalidRules;
  }

  /**
   * List of rules that were specified in the request, but which the server did not know how to
   * instantiate.
   * The value set may be {@code null}.
   */
  public Result setInvalidRules(java.util.List<String> invalidRules) {
    this.invalidRules = invalidRules;
    return this;
  }

  /**
   * Kind of result.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind of result.
   * The value set may be {@code null}.
   */
  public Result setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Notice to discourage users from reusing API keys.
   * The value returned may be {@code null}.
   */
  public String getNotice() {
    return notice;
  }

  /**
   * Notice to discourage users from reusing API keys.
   * The value set may be {@code null}.
   */
  public Result setNotice(String notice) {
    this.notice = notice;
    return this;
  }

  /**
   * Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
   * The value returned may be {@code null}.
   */
  public PageStats getPageStats() {
    return pageStats;
  }

  /**
   * Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
   * The value set may be {@code null}.
   */
  public Result setPageStats(PageStats pageStats) {
    this.pageStats = pageStats;
    return this;
  }

  /**
   * Echo of certain request parameters.
   * The value returned may be {@code null}.
   */
  public Request getRequest() {
    return request;
  }

  /**
   * Echo of certain request parameters.
   * The value set may be {@code null}.
   */
  public Result setRequest(Request request) {
    this.request = request;
    return this;
  }

  /**
   * Response code for the document. 200 indicates a normal page load. 4xx/5xx indicates an error.
   * The value returned may be {@code null}.
   */
  public Integer getResponseCode() {
    return responseCode;
  }

  /**
   * Response code for the document. 200 indicates a normal page load. 4xx/5xx indicates an error.
   * The value set may be {@code null}.
   */
  public Result setResponseCode(Integer responseCode) {
    this.responseCode = responseCode;
    return this;
  }

  /**
   * The Page Speed Score (0-100), which indicates how much faster a page could be. A high score
   * indicates little room for improvement, while a lower score indicates more room for improvement.
   * The value returned may be {@code null}.
   */
  public Integer getScore() {
    return score;
  }

  /**
   * The Page Speed Score (0-100), which indicates how much faster a page could be. A high score
   * indicates little room for improvement, while a lower score indicates more room for improvement.
   * The value set may be {@code null}.
   */
  public Result setScore(Integer score) {
    this.score = score;
    return this;
  }

  /**
   * Base64 encoded screenshot of the page that was analyzed.
   * The value returned may be {@code null}.
   */
  public Screenshot getScreenshot() {
    return screenshot;
  }

  /**
   * Base64 encoded screenshot of the page that was analyzed.
   * The value set may be {@code null}.
   */
  public Result setScreenshot(Screenshot screenshot) {
    this.screenshot = screenshot;
    return this;
  }

  /**
   * Title of the page, as displayed in the browser's title bar.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Title of the page, as displayed in the browser's title bar.
   * The value set may be {@code null}.
   */
  public Result setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * The version of the Page Speed SDK used to generate these results.
   * The value returned may be {@code null}.
   */
  public Version getVersion() {
    return version;
  }

  /**
   * The version of the Page Speed SDK used to generate these results.
   * The value set may be {@code null}.
   */
  public Result setVersion(Version version) {
    this.version = version;
    return this;
  }

  /**
   * Localized Page Speed results. Contains a ruleResults entry for each Page Speed rule instantiated
   * and run by the server.
   */
  public static final class FormattedResults extends GenericJson {

    /**
     * The locale of the formattedResults, e.g. "en_US".
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String locale;

    /**
     * Dictionary of formatted rule results, with one entry for each Page Speed rule instantiated and
     * run by the server.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.Map<String, RuleResultsElement> ruleResults;

    static {
      // hack to force ProGuard to consider RuleResultsElement used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(RuleResultsElement.class);
    }

    /**
     * The locale of the formattedResults, e.g. "en_US".
     * The value returned may be {@code null}.
     */
    public String getLocale() {
      return locale;
    }

    /**
     * The locale of the formattedResults, e.g. "en_US".
     * The value set may be {@code null}.
     */
    public FormattedResults setLocale(String locale) {
      this.locale = locale;
      return this;
    }

    /**
     * Dictionary of formatted rule results, with one entry for each Page Speed rule instantiated and
     * run by the server.
     * The value returned may be {@code null}.
     */
    public java.util.Map<String, RuleResultsElement> getRuleResults() {
      return ruleResults;
    }

    /**
     * Dictionary of formatted rule results, with one entry for each Page Speed rule instantiated and
     * run by the server.
     * The value set may be {@code null}.
     */
    public FormattedResults setRuleResults(java.util.Map<String, RuleResultsElement> ruleResults) {
      this.ruleResults = ruleResults;
      return this;
    }

    /**
     * The enum-like identifier for this rule. For instance "EnableKeepAlive" or "AvoidCssImport". Not
     * localized.
     */
    public static final class RuleResultsElement extends GenericJson {

      /**
       * Localized name of the rule, intended for presentation to a user.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String localizedRuleName;

      /**
       * The impact (unbounded floating point value) that implementing the suggestions for this rule
       * would have on making the page faster. Impact is comparable between rules to determine which
       * rule's suggestions would have a higher or lower impact on making a page faster. For instance,
       * if enabling compression would save 1MB, while optimizing images would save 500kB, the enable
       * compression rule would have 2x the impact of the image optimization rule, all other things
       * being equal.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Double ruleImpact;

      /**
       * The score (0-100) for this rule. The rule score indicates how well a page implements the
       * recommendations for the given rule. For instance, if none of the compressible resources on a
       * page are compressed, the rule score would be 0, while if all of the compressible resources on a
       * page are compressed, the rule score would be 100.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Integer ruleScore;

      /**
       * List of blocks of URLs. Each block may contain a heading and a list of URLs. Each URL may
       * optionally include additional details.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private java.util.List<UrlBlocks> urlBlocks;

      static {
        // hack to force ProGuard to consider UrlBlocks used, since otherwise it would be stripped out
        // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
        com.google.api.client.util.Data.nullOf(UrlBlocks.class);
      }

      /**
       * Localized name of the rule, intended for presentation to a user.
       * The value returned may be {@code null}.
       */
      public String getLocalizedRuleName() {
        return localizedRuleName;
      }

      /**
       * Localized name of the rule, intended for presentation to a user.
       * The value set may be {@code null}.
       */
      public RuleResultsElement setLocalizedRuleName(String localizedRuleName) {
        this.localizedRuleName = localizedRuleName;
        return this;
      }

      /**
       * The impact (unbounded floating point value) that implementing the suggestions for this rule
       * would have on making the page faster. Impact is comparable between rules to determine which
       * rule's suggestions would have a higher or lower impact on making a page faster. For instance,
       * if enabling compression would save 1MB, while optimizing images would save 500kB, the enable
       * compression rule would have 2x the impact of the image optimization rule, all other things
       * being equal.
       * The value returned may be {@code null}.
       */
      public Double getRuleImpact() {
        return ruleImpact;
      }

      /**
       * The impact (unbounded floating point value) that implementing the suggestions for this rule
       * would have on making the page faster. Impact is comparable between rules to determine which
       * rule's suggestions would have a higher or lower impact on making a page faster. For instance,
       * if enabling compression would save 1MB, while optimizing images would save 500kB, the enable
       * compression rule would have 2x the impact of the image optimization rule, all other things
       * being equal.
       * The value set may be {@code null}.
       */
      public RuleResultsElement setRuleImpact(Double ruleImpact) {
        this.ruleImpact = ruleImpact;
        return this;
      }

      /**
       * The score (0-100) for this rule. The rule score indicates how well a page implements the
       * recommendations for the given rule. For instance, if none of the compressible resources on a
       * page are compressed, the rule score would be 0, while if all of the compressible resources on a
       * page are compressed, the rule score would be 100.
       * The value returned may be {@code null}.
       */
      public Integer getRuleScore() {
        return ruleScore;
      }

      /**
       * The score (0-100) for this rule. The rule score indicates how well a page implements the
       * recommendations for the given rule. For instance, if none of the compressible resources on a
       * page are compressed, the rule score would be 0, while if all of the compressible resources on a
       * page are compressed, the rule score would be 100.
       * The value set may be {@code null}.
       */
      public RuleResultsElement setRuleScore(Integer ruleScore) {
        this.ruleScore = ruleScore;
        return this;
      }

      /**
       * List of blocks of URLs. Each block may contain a heading and a list of URLs. Each URL may
       * optionally include additional details.
       * The value returned may be {@code null}.
       */
      public java.util.List<UrlBlocks> getUrlBlocks() {
        return urlBlocks;
      }

      /**
       * List of blocks of URLs. Each block may contain a heading and a list of URLs. Each URL may
       * optionally include additional details.
       * The value set may be {@code null}.
       */
      public RuleResultsElement setUrlBlocks(java.util.List<UrlBlocks> urlBlocks) {
        this.urlBlocks = urlBlocks;
        return this;
      }

      /**
       * Model definition for ResultFormattedResultsRuleResultsElementUrlBlocks.
       */
      public static final class UrlBlocks extends GenericJson {

        /**
         * Heading to be displayed with the list of URLs.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Header header;

        /**
         * List of entries that provide information about URLs in the url block. Optional.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private java.util.List<Urls> urls;

        static {
          // hack to force ProGuard to consider Urls used, since otherwise it would be stripped out
          // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
          com.google.api.client.util.Data.nullOf(Urls.class);
        }

        /**
         * Heading to be displayed with the list of URLs.
         * The value returned may be {@code null}.
         */
        public Header getHeader() {
          return header;
        }

        /**
         * Heading to be displayed with the list of URLs.
         * The value set may be {@code null}.
         */
        public UrlBlocks setHeader(Header header) {
          this.header = header;
          return this;
        }

        /**
         * List of entries that provide information about URLs in the url block. Optional.
         * The value returned may be {@code null}.
         */
        public java.util.List<Urls> getUrls() {
          return urls;
        }

        /**
         * List of entries that provide information about URLs in the url block. Optional.
         * The value set may be {@code null}.
         */
        public UrlBlocks setUrls(java.util.List<Urls> urls) {
          this.urls = urls;
          return this;
        }

        /**
         * Heading to be displayed with the list of URLs.
         */
        public static final class Header extends GenericJson {

          /**
           * List of arguments for the format string.
           * The value may be {@code null}.
           */
          @com.google.api.client.util.Key
          private java.util.List<Args> args;

          static {
            // hack to force ProGuard to consider Args used, since otherwise it would be stripped out
            // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
            com.google.api.client.util.Data.nullOf(Args.class);
          }

          /**
           * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
           * 'Minifying the following $1 resources would save a total of $2 bytes'.
           * The value may be {@code null}.
           */
          @com.google.api.client.util.Key
          private String format;

          /**
           * List of arguments for the format string.
           * The value returned may be {@code null}.
           */
          public java.util.List<Args> getArgs() {
            return args;
          }

          /**
           * List of arguments for the format string.
           * The value set may be {@code null}.
           */
          public Header setArgs(java.util.List<Args> args) {
            this.args = args;
            return this;
          }

          /**
           * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
           * 'Minifying the following $1 resources would save a total of $2 bytes'.
           * The value returned may be {@code null}.
           */
          public String getFormat() {
            return format;
          }

          /**
           * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
           * 'Minifying the following $1 resources would save a total of $2 bytes'.
           * The value set may be {@code null}.
           */
          public Header setFormat(String format) {
            this.format = format;
            return this;
          }

          /**
           * Model definition for ResultFormattedResultsRuleResultsElementUrlBlocksHeaderArgs.
           */
          public static final class Args extends GenericJson {

            /**
             * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
             * The value may be {@code null}.
             */
            @com.google.api.client.util.Key
            private String type;

            /**
             * Argument value, as a localized string.
             * The value may be {@code null}.
             */
            @com.google.api.client.util.Key
            private String value;

            /**
             * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
             * The value returned may be {@code null}.
             */
            public String getType() {
              return type;
            }

            /**
             * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
             * The value set may be {@code null}.
             */
            public Args setType(String type) {
              this.type = type;
              return this;
            }

            /**
             * Argument value, as a localized string.
             * The value returned may be {@code null}.
             */
            public String getValue() {
              return value;
            }

            /**
             * Argument value, as a localized string.
             * The value set may be {@code null}.
             */
            public Args setValue(String value) {
              this.value = value;
              return this;
            }

          }
        }
        /**
         * Model definition for ResultFormattedResultsRuleResultsElementUrlBlocksUrls.
         */
        public static final class Urls extends GenericJson {

          /**
           * List of entries that provide additional details about a single URL. Optional.
           * The value may be {@code null}.
           */
          @com.google.api.client.util.Key
          private java.util.List<Details> details;

          static {
            // hack to force ProGuard to consider Details used, since otherwise it would be stripped out
            // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
            com.google.api.client.util.Data.nullOf(Details.class);
          }

          /**
           * A format string that gives information about the URL, and a list of arguments for that format
           * string.
           * The value may be {@code null}.
           */
          @com.google.api.client.util.Key
          private ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResult result;

          /**
           * List of entries that provide additional details about a single URL. Optional.
           * The value returned may be {@code null}.
           */
          public java.util.List<Details> getDetails() {
            return details;
          }

          /**
           * List of entries that provide additional details about a single URL. Optional.
           * The value set may be {@code null}.
           */
          public Urls setDetails(java.util.List<Details> details) {
            this.details = details;
            return this;
          }

          /**
           * A format string that gives information about the URL, and a list of arguments for that format
           * string.
           * The value returned may be {@code null}.
           */
          public ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResult getResult() {
            return result;
          }

          /**
           * A format string that gives information about the URL, and a list of arguments for that format
           * string.
           * The value set may be {@code null}.
           */
          public Urls setResult(ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResult result) {
            this.result = result;
            return this;
          }

          /**
           * Model definition for ResultFormattedResultsRuleResultsElementUrlBlocksUrlsDetails.
           */
          public static final class Details extends GenericJson {

            /**
             * List of arguments for the format string.
             * The value may be {@code null}.
             */
            @com.google.api.client.util.Key
            private java.util.List<Args> args;

            static {
              // hack to force ProGuard to consider Args used, since otherwise it would be stripped out
              // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
              com.google.api.client.util.Data.nullOf(Args.class);
            }

            /**
             * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
             * 'Unnecessary metadata for this resource adds an additional $1 bytes to its download size'.
             * The value may be {@code null}.
             */
            @com.google.api.client.util.Key
            private String format;

            /**
             * List of arguments for the format string.
             * The value returned may be {@code null}.
             */
            public java.util.List<Args> getArgs() {
              return args;
            }

            /**
             * List of arguments for the format string.
             * The value set may be {@code null}.
             */
            public Details setArgs(java.util.List<Args> args) {
              this.args = args;
              return this;
            }

            /**
             * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
             * 'Unnecessary metadata for this resource adds an additional $1 bytes to its download size'.
             * The value returned may be {@code null}.
             */
            public String getFormat() {
              return format;
            }

            /**
             * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
             * 'Unnecessary metadata for this resource adds an additional $1 bytes to its download size'.
             * The value set may be {@code null}.
             */
            public Details setFormat(String format) {
              this.format = format;
              return this;
            }

            /**
             * Model definition for ResultFormattedResultsRuleResultsElementUrlBlocksUrlsDetailsArgs.
             */
            public static final class Args extends GenericJson {

              /**
               * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
               * The value may be {@code null}.
               */
              @com.google.api.client.util.Key
              private String type;

              /**
               * Argument value, as a localized string.
               * The value may be {@code null}.
               */
              @com.google.api.client.util.Key
              private String value;

              /**
               * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
               * The value returned may be {@code null}.
               */
              public String getType() {
                return type;
              }

              /**
               * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
               * The value set may be {@code null}.
               */
              public Args setType(String type) {
                this.type = type;
                return this;
              }

              /**
               * Argument value, as a localized string.
               * The value returned may be {@code null}.
               */
              public String getValue() {
                return value;
              }

              /**
               * Argument value, as a localized string.
               * The value set may be {@code null}.
               */
              public Args setValue(String value) {
                this.value = value;
                return this;
              }

            }
          }
          /**
           * A format string that gives information about the URL, and a list of arguments for that format
           * string.
           */
          public static final class ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResult extends GenericJson {

            /**
             * List of arguments for the format string.
             * The value may be {@code null}.
             */
            @com.google.api.client.util.Key
            private java.util.List<Args> args;

            static {
              // hack to force ProGuard to consider Args used, since otherwise it would be stripped out
              // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
              com.google.api.client.util.Data.nullOf(Args.class);
            }

            /**
             * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
             * 'Minifying the resource at URL $1 can save $2 bytes'.
             * The value may be {@code null}.
             */
            @com.google.api.client.util.Key
            private String format;

            /**
             * List of arguments for the format string.
             * The value returned may be {@code null}.
             */
            public java.util.List<Args> getArgs() {
              return args;
            }

            /**
             * List of arguments for the format string.
             * The value set may be {@code null}.
             */
            public ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResult setArgs(java.util.List<Args> args) {
              this.args = args;
              return this;
            }

            /**
             * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
             * 'Minifying the resource at URL $1 can save $2 bytes'.
             * The value returned may be {@code null}.
             */
            public String getFormat() {
              return format;
            }

            /**
             * A localized format string with $N placeholders, where N is the 1-indexed argument number, e.g.
             * 'Minifying the resource at URL $1 can save $2 bytes'.
             * The value set may be {@code null}.
             */
            public ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResult setFormat(String format) {
              this.format = format;
              return this;
            }

            /**
             * Model definition for ResultFormattedResultsRuleResultsElementUrlBlocksUrlsResultArgs.
             */
            public static final class Args extends GenericJson {

              /**
               * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
               * The value may be {@code null}.
               */
              @com.google.api.client.util.Key
              private String type;

              /**
               * Argument value, as a localized string.
               * The value may be {@code null}.
               */
              @com.google.api.client.util.Key
              private String value;

              /**
               * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
               * The value returned may be {@code null}.
               */
              public String getType() {
                return type;
              }

              /**
               * Type of argument. One of URL, STRING_LITERAL, INT_LITERAL, BYTES, or DURATION.
               * The value set may be {@code null}.
               */
              public Args setType(String type) {
                this.type = type;
                return this;
              }

              /**
               * Argument value, as a localized string.
               * The value returned may be {@code null}.
               */
              public String getValue() {
                return value;
              }

              /**
               * Argument value, as a localized string.
               * The value set may be {@code null}.
               */
              public Args setValue(String value) {
                this.value = value;
                return this;
              }

            }
          }
        }
      }
    }
  }

  /**
   * Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
   */
  public static final class PageStats extends GenericJson {

    /**
     * Number of uncompressed response bytes for CSS resources on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long cssResponseBytes;

    /**
     * Number of response bytes for flash resources on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long flashResponseBytes;

    /**
     * Number of uncompressed response bytes for the main HTML document and all iframes on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long htmlResponseBytes;

    /**
     * Number of response bytes for image resources on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long imageResponseBytes;

    /**
     * Number of uncompressed response bytes for JS resources on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long javascriptResponseBytes;

    /**
     * Number of CSS resources referenced by the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer numberCssResources;

    /**
     * Number of unique hosts referenced by the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer numberHosts;

    /**
     * Number of JavaScript resources referenced by the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer numberJsResources;

    /**
     * Number of HTTP resources loaded by the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer numberResources;

    /**
     * Number of static (i.e. cacheable) resources on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer numberStaticResources;

    /**
     * Number of response bytes for other resources on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long otherResponseBytes;

    /**
     * Number of uncompressed response bytes for text resources not covered by other statistics (i.e
     * non-HTML, non-script, non-CSS resources) on the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long textResponseBytes;

    /**
     * Total size of all request bytes sent by the page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long totalRequestBytes;

    /**
     * Number of uncompressed response bytes for CSS resources on the page.
     * The value returned may be {@code null}.
     */
    public Long getCssResponseBytes() {
      return cssResponseBytes;
    }

    /**
     * Number of uncompressed response bytes for CSS resources on the page.
     * The value set may be {@code null}.
     */
    public PageStats setCssResponseBytes(Long cssResponseBytes) {
      this.cssResponseBytes = cssResponseBytes;
      return this;
    }

    /**
     * Number of response bytes for flash resources on the page.
     * The value returned may be {@code null}.
     */
    public Long getFlashResponseBytes() {
      return flashResponseBytes;
    }

    /**
     * Number of response bytes for flash resources on the page.
     * The value set may be {@code null}.
     */
    public PageStats setFlashResponseBytes(Long flashResponseBytes) {
      this.flashResponseBytes = flashResponseBytes;
      return this;
    }

    /**
     * Number of uncompressed response bytes for the main HTML document and all iframes on the page.
     * The value returned may be {@code null}.
     */
    public Long getHtmlResponseBytes() {
      return htmlResponseBytes;
    }

    /**
     * Number of uncompressed response bytes for the main HTML document and all iframes on the page.
     * The value set may be {@code null}.
     */
    public PageStats setHtmlResponseBytes(Long htmlResponseBytes) {
      this.htmlResponseBytes = htmlResponseBytes;
      return this;
    }

    /**
     * Number of response bytes for image resources on the page.
     * The value returned may be {@code null}.
     */
    public Long getImageResponseBytes() {
      return imageResponseBytes;
    }

    /**
     * Number of response bytes for image resources on the page.
     * The value set may be {@code null}.
     */
    public PageStats setImageResponseBytes(Long imageResponseBytes) {
      this.imageResponseBytes = imageResponseBytes;
      return this;
    }

    /**
     * Number of uncompressed response bytes for JS resources on the page.
     * The value returned may be {@code null}.
     */
    public Long getJavascriptResponseBytes() {
      return javascriptResponseBytes;
    }

    /**
     * Number of uncompressed response bytes for JS resources on the page.
     * The value set may be {@code null}.
     */
    public PageStats setJavascriptResponseBytes(Long javascriptResponseBytes) {
      this.javascriptResponseBytes = javascriptResponseBytes;
      return this;
    }

    /**
     * Number of CSS resources referenced by the page.
     * The value returned may be {@code null}.
     */
    public Integer getNumberCssResources() {
      return numberCssResources;
    }

    /**
     * Number of CSS resources referenced by the page.
     * The value set may be {@code null}.
     */
    public PageStats setNumberCssResources(Integer numberCssResources) {
      this.numberCssResources = numberCssResources;
      return this;
    }

    /**
     * Number of unique hosts referenced by the page.
     * The value returned may be {@code null}.
     */
    public Integer getNumberHosts() {
      return numberHosts;
    }

    /**
     * Number of unique hosts referenced by the page.
     * The value set may be {@code null}.
     */
    public PageStats setNumberHosts(Integer numberHosts) {
      this.numberHosts = numberHosts;
      return this;
    }

    /**
     * Number of JavaScript resources referenced by the page.
     * The value returned may be {@code null}.
     */
    public Integer getNumberJsResources() {
      return numberJsResources;
    }

    /**
     * Number of JavaScript resources referenced by the page.
     * The value set may be {@code null}.
     */
    public PageStats setNumberJsResources(Integer numberJsResources) {
      this.numberJsResources = numberJsResources;
      return this;
    }

    /**
     * Number of HTTP resources loaded by the page.
     * The value returned may be {@code null}.
     */
    public Integer getNumberResources() {
      return numberResources;
    }

    /**
     * Number of HTTP resources loaded by the page.
     * The value set may be {@code null}.
     */
    public PageStats setNumberResources(Integer numberResources) {
      this.numberResources = numberResources;
      return this;
    }

    /**
     * Number of static (i.e. cacheable) resources on the page.
     * The value returned may be {@code null}.
     */
    public Integer getNumberStaticResources() {
      return numberStaticResources;
    }

    /**
     * Number of static (i.e. cacheable) resources on the page.
     * The value set may be {@code null}.
     */
    public PageStats setNumberStaticResources(Integer numberStaticResources) {
      this.numberStaticResources = numberStaticResources;
      return this;
    }

    /**
     * Number of response bytes for other resources on the page.
     * The value returned may be {@code null}.
     */
    public Long getOtherResponseBytes() {
      return otherResponseBytes;
    }

    /**
     * Number of response bytes for other resources on the page.
     * The value set may be {@code null}.
     */
    public PageStats setOtherResponseBytes(Long otherResponseBytes) {
      this.otherResponseBytes = otherResponseBytes;
      return this;
    }

    /**
     * Number of uncompressed response bytes for text resources not covered by other statistics (i.e
     * non-HTML, non-script, non-CSS resources) on the page.
     * The value returned may be {@code null}.
     */
    public Long getTextResponseBytes() {
      return textResponseBytes;
    }

    /**
     * Number of uncompressed response bytes for text resources not covered by other statistics (i.e
     * non-HTML, non-script, non-CSS resources) on the page.
     * The value set may be {@code null}.
     */
    public PageStats setTextResponseBytes(Long textResponseBytes) {
      this.textResponseBytes = textResponseBytes;
      return this;
    }

    /**
     * Total size of all request bytes sent by the page.
     * The value returned may be {@code null}.
     */
    public Long getTotalRequestBytes() {
      return totalRequestBytes;
    }

    /**
     * Total size of all request bytes sent by the page.
     * The value set may be {@code null}.
     */
    public PageStats setTotalRequestBytes(Long totalRequestBytes) {
      this.totalRequestBytes = totalRequestBytes;
      return this;
    }

  }

  /**
   * Echo of certain request parameters.
   */
  public static final class Request extends GenericJson {

    /**
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key("filter_third_party_resources")
    private String filterThirdPartyResources;

    /**
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String strategy;

    /**
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**

     * The value returned may be {@code null}.
     */
    public String getFilterThirdPartyResources() {
      return filterThirdPartyResources;
    }

    /**

     * The value set may be {@code null}.
     */
    public Request setFilterThirdPartyResources(String filterThirdPartyResources) {
      this.filterThirdPartyResources = filterThirdPartyResources;
      return this;
    }

    /**

     * The value returned may be {@code null}.
     */
    public String getStrategy() {
      return strategy;
    }

    /**

     * The value set may be {@code null}.
     */
    public Request setStrategy(String strategy) {
      this.strategy = strategy;
      return this;
    }

    /**

     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**

     * The value set may be {@code null}.
     */
    public Request setUrl(String url) {
      this.url = url;
      return this;
    }

  }

  /**
   * Base64 encoded screenshot of the page that was analyzed.
   */
  public static final class Screenshot extends GenericJson {

    /**
     * Image data base64 encoded.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String data;

    /**
     * Height of screenshot in pixels.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer height;

    /**
     * Mime type of image data. E.g. "image/jpeg".
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key("mime_type")
    private String mimeType;

    /**
     * Width of screenshot in pixels.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer width;

    /**
     * Image data base64 encoded.
     * The value returned may be {@code null}.
     */
    public String getData() {
      return data;
    }

    /**
     * Image data base64 encoded.
     * The value set may be {@code null}.
     */
    public Screenshot setData(String data) {
      this.data = data;
      return this;
    }

    /**
     * Height of screenshot in pixels.
     * The value returned may be {@code null}.
     */
    public Integer getHeight() {
      return height;
    }

    /**
     * Height of screenshot in pixels.
     * The value set may be {@code null}.
     */
    public Screenshot setHeight(Integer height) {
      this.height = height;
      return this;
    }

    /**
     * Mime type of image data. E.g. "image/jpeg".
     * The value returned may be {@code null}.
     */
    public String getMimeType() {
      return mimeType;
    }

    /**
     * Mime type of image data. E.g. "image/jpeg".
     * The value set may be {@code null}.
     */
    public Screenshot setMimeType(String mimeType) {
      this.mimeType = mimeType;
      return this;
    }

    /**
     * Width of screenshot in pixels.
     * The value returned may be {@code null}.
     */
    public Integer getWidth() {
      return width;
    }

    /**
     * Width of screenshot in pixels.
     * The value set may be {@code null}.
     */
    public Screenshot setWidth(Integer width) {
      this.width = width;
      return this;
    }

  }

  /**
   * The version of the Page Speed SDK used to generate these results.
   */
  public static final class Version extends GenericJson {

    /**
     * The major version number of the Page Speed SDK used to generate these results.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer major;

    /**
     * The minor version number of the Page Speed SDK used to generate these results.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer minor;

    /**
     * The major version number of the Page Speed SDK used to generate these results.
     * The value returned may be {@code null}.
     */
    public Integer getMajor() {
      return major;
    }

    /**
     * The major version number of the Page Speed SDK used to generate these results.
     * The value set may be {@code null}.
     */
    public Version setMajor(Integer major) {
      this.major = major;
      return this;
    }

    /**
     * The minor version number of the Page Speed SDK used to generate these results.
     * The value returned may be {@code null}.
     */
    public Integer getMinor() {
      return minor;
    }

    /**
     * The minor version number of the Page Speed SDK used to generate these results.
     * The value set may be {@code null}.
     */
    public Version setMinor(Integer minor) {
      this.minor = minor;
      return this;
    }

  }
}
